pub fn gen_error_response(code: u16) -> ResponseHeaderExpand description
Generate an error response with the given status code.
This error response has a zero Content-Length and Cache-Control: private, no-store.
pub fn gen_error_response(code: u16) -> ResponseHeaderGenerate an error response with the given status code.
This error response has a zero Content-Length and Cache-Control: private, no-store.